@@ -7,4 +7,4 @@ class SettingAdmin(admin.ModelAdmin):
     pass
 
 
-admin.site.re(Setting,SettingAdmin)
+admin.site.register(Setting, SettingAdmin)
